==> haskell-integer-logarithms-1.0.2.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: integer-logarithms
version: 1.0.2.2
id: integer-logarithms-1.0.2.2-33gHWvkkotvKqvHmbqy5m0
key: integer-logarithms-1.0.2.2-33gHWvkkotvKqvHmbqy5m0
license: MIT
copyright: (c) 2011 Daniel Fischer
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Daniel Fischer
stability: Provisional
homepage: https://github.com/Bodigrim/integer-logarithms
synopsis: Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.
    .
    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.
category: Math, Algorithms, Number Theory
abi: e0973d6eca2bc234a9a59aa682a163bc
exposed: True
exposed-modules:
    GHC.Integer.Logarithms.Compat Math.NumberTheory.Logarithms
    Math.NumberTheory.Powers.Integer Math.NumberTheory.Powers.Natural
import-dirs: /usr/lib/ghc-8.6.4/site-local/integer-logarithms-1.0.2.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/integer-logarithms-1.0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/integer-logarithms-1.0.2.2
hs-libraries: HSinteger-logarithms-1.0.2.2-33gHWvkkotvKqvHmbqy5m0
depends:
    array-0.5.3.0 base-4.12.0.0 ghc-prim-0.5.3 integer-gmp-1.0.2.0
haddock-interfaces: /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock
haddock-html: /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-integer-logarithms-1.0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: integer-logarithms
version: 1.0.3
id: integer-logarithms-1.0.3-4fjS4bKV0939VXcQKK2I7B
key: integer-logarithms-1.0.3-4fjS4bKV0939VXcQKK2I7B
license: MIT
copyright: (c) 2011 Daniel Fischer
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Daniel Fischer
stability: Provisional
homepage: https://github.com/Bodigrim/integer-logarithms
synopsis: Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.
    .
    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.
category: Math, Algorithms, Number Theory
abi: 0a28c567f4584154a7579be56d6e114f
exposed: True
exposed-modules:
    GHC.Integer.Logarithms.Compat Math.NumberTheory.Logarithms
    Math.NumberTheory.Powers.Integer Math.NumberTheory.Powers.Natural
import-dirs: /usr/lib/ghc-8.6.4/site-local/integer-logarithms-1.0.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/integer-logarithms-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/integer-logarithms-1.0.3
hs-libraries: HSinteger-logarithms-1.0.3-4fjS4bKV0939VXcQKK2I7B
depends:
    array-0.5.3.0 base-4.12.0.0 ghc-prim-0.5.3 integer-gmp-1.0.2.0
haddock-interfaces: /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock
haddock-html: /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
